Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1134)

Unified Diff: chrome/android/java/src/org/chromium/chrome/browser/pageinfo/WebsiteSettingsPopup.java

Issue 1740063002: [Offline pages] Adding the status icon to the OIB (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@omnibox-patch-2
Patch Set: Updating content description for the icon Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/java/src/org/chromium/chrome/browser/pageinfo/WebsiteSettingsPopup.java
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/pageinfo/WebsiteSettingsPopup.java b/chrome/android/java/src/org/chromium/chrome/browser/pageinfo/WebsiteSettingsPopup.java
index 77ae5c07127a6a11e27ff3e282439600159bbef5..e1d39ceac5077d954e60f02715d9aa8ab94b0e2d 100644
--- a/chrome/android/java/src/org/chromium/chrome/browser/pageinfo/WebsiteSettingsPopup.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/pageinfo/WebsiteSettingsPopup.java
@@ -400,13 +400,17 @@ public class WebsiteSettingsPopup implements OnClickListener {
}
});
- // Work out the URL and connection message.
+ // Work out the URL and connection message and status visibility.
+ int statusIconVisibility = View.GONE;
if (isShowingOfflinePage()) {
mFullUrl = mOfflinePageOriginalUrl;
+ statusIconVisibility = View.VISIBLE;
} else {
mFullUrl = mWebContents.getVisibleUrl();
}
+ mContainer.findViewById(R.id.offline_icon).setVisibility(statusIconVisibility);
+
try {
mParsedUrl = new URI(mFullUrl);
mIsInternalPage = UrlUtilities.isInternalScheme(mParsedUrl);
« no previous file with comments | « chrome/android/java/res/layout/website_settings.xml ('k') | chrome/android/java/strings/android_chrome_strings.grd » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698